# Canvas

The `pikepdf.canvas` provides a low-level PDF rendering API.

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.Canvas
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas._CanvasAccessor
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.ContentStreamBuilder
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.LoadedImage
    :members:
```

## Text and fonts

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.Text
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.TextDirection
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.Font
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.Helvetica
    :members:
```

```{eval-rst}
.. autoapiclass:: pikepdf.canvas.SimpleFont
    :members:
```
